config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/iproute2/ematch_map.new
config etc/iproute2/rt_dsfield.new
config etc/iproute2/rt_protos.new
config etc/iproute2/rt_realms.new
config etc/iproute2/rt_scopes.new
config etc/iproute2/rt_tables.new

( cd usr/man/man8 ; rm -rf rtstat.8.gz )
( cd usr/man/man8 ; ln -sf lnstat.8.gz rtstat.8.gz )
( cd usr/man/man8 ; rm -rf ctstat.8.gz )
( cd usr/man/man8 ; ln -sf lnstat.8.gz ctstat.8.gz )
( cd usr/man/man8 ; rm -rf routef.8.gz )
( cd usr/man/man8 ; ln -sf routel.8.gz routef.8.gz )
( cd usr/man/man8 ; rm -rf nstat.8.gz )
( cd usr/man/man8 ; ln -sf rtacct.8.gz nstat.8.gz )
( cd usr/man/man8 ; rm -rf tc-pfifo.8.gz )
( cd usr/man/man8 ; ln -sf tc-bfifo.8.gz tc-pfifo.8.gz )
( cd usr/sbin ; rm -rf ip )
( cd usr/sbin ; ln -sf ../../sbin/ip ip )
( cd usr/sbin ; rm -rf tc )
( cd usr/sbin ; ln -sf ../../sbin/tc tc )
( cd usr/sbin ; rm -rf ss )
( cd usr/sbin ; ln -sf ../../sbin/ss ss )
( cd usr/sbin ; rm -rf arpd )
( cd usr/sbin ; ln -sf ../../sbin/arpd arpd )
( cd usr/sbin ; rm -rf genl )
( cd usr/sbin ; ln -sf ../../sbin/genl genl )
( cd usr/sbin ; rm -rf rtpr )
( cd usr/sbin ; ln -sf ../../sbin/rtpr rtpr )
( cd usr/sbin ; rm -rf ifcfg )
( cd usr/sbin ; ln -sf ../../sbin/ifcfg ifcfg )
( cd usr/sbin ; rm -rf nstat )
( cd usr/sbin ; ln -sf ../../sbin/nstat nstat )
( cd usr/sbin ; rm -rf rtmon )
( cd usr/sbin ; ln -sf ../../sbin/rtmon rtmon )
( cd usr/sbin ; rm -rf ctstat )
( cd usr/sbin ; ln -sf ../../sbin/ctstat ctstat )
( cd usr/sbin ; rm -rf ifstat )
( cd usr/sbin ; ln -sf ../../sbin/ifstat ifstat )
( cd usr/sbin ; rm -rf lnstat )
( cd usr/sbin ; ln -sf ../../sbin/lnstat lnstat )
( cd usr/sbin ; rm -rf routef )
( cd usr/sbin ; ln -sf ../../sbin/routef routef )
( cd usr/sbin ; rm -rf routel )
( cd usr/sbin ; ln -sf ../../sbin/routel routel )
( cd usr/sbin ; rm -rf rtacct )
( cd usr/sbin ; ln -sf ../../sbin/rtacct rtacct )
( cd usr/sbin ; rm -rf rtstat )
( cd usr/sbin ; ln -sf ../../sbin/rtstat rtstat )
( cd sbin ; rm -rf ctstat )
( cd sbin ; ln -sf lnstat ctstat )
( cd sbin ; rm -rf rtstat )
( cd sbin ; ln -sf lnstat rtstat )
